        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>50</strong> miembros: 23 <strong>control</strong><br>0,3,5,6,9,10,14,16,18,19,22,23,25,34,38,41,42,44,45,46,47,49,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 19 <br>1,4,7,8,11,13,15,17,26,27,28,29,31,32,33,36,37,40,48';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 9 <br>2,12,20,21,24,30,35,39,43';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>50</strong> miembros: 23 <strong>control</strong><br>0,3,5,6,9,10,14,16,18,19,22,23,25,34,38,41,42,44,45,46,47,49,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 19 <br>1,4,7,8,11,13,15,17,26,27,28,29,31,32,33,36,37,40,48';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 9 <br>2,12,20,21,24,30,35,39,43';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>50</strong> miembros: 23 <strong>control</strong><br>0,3,5,6,9,10,14,16,18,19,22,23,25,34,38,41,42,44,45,46,47,49,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 19 <br>1,4,7,8,11,13,15,17,26,27,28,29,31,32,33,36,37,40,48';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 9 <br>2,12,20,21,24,30,35,39,43';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>50</strong> miembros: 23 <strong>control</strong><br>0,3,5,6,9,10,14,16,18,19,22,23,25,34,38,41,42,44,45,46,47,49,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 19 <br>1,4,7,8,11,13,15,17,26,27,28,29,31,32,33,36,37,40,48';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 9 <br>2,12,20,21,24,30,35,39,43';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>50</strong> miembros: 23 <strong>control</strong><br>0,3,5,6,9,10,14,16,18,19,22,23,25,34,38,41,42,44,45,46,47,49,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 19 <br>1,4,7,8,11,13,15,17,26,27,28,29,31,32,33,36,37,40,48';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 9 <br>2,12,20,21,24,30,35,39,43';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>50</strong> miembros: 23 <strong>control</strong><br>0,3,5,6,9,10,14,16,18,19,22,23,25,34,38,41,42,44,45,46,47,49,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>48</strong> miembros: 19 <br>1,4,7,8,11,13,15,17,26,27,28,29,31,32,33,36,37,40,48';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260621 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>39</strong> miembros: 9 <br>2,12,20,21,24,30,35,39,43';}
}
